'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _buildEnum = require('../buildEnum');

var _buildEnum2 = _interopRequireDefault(_buildEnum);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const generateEnumAST = ({ description, name = 'Enum', values = ['VALUE'] } = {}) => (0, _language.parse)(`
  # ${ description === undefined ? '' : description }
  enum ${ name } {
    ${ values.join('\n') }
  }
`).definitions[0]; /* eslint-env jest */

const generateEnumValueConfigMap = ({
  name = 'VALUE',
  value = 'VALUE',
  description,
  deprecationReason
} = {}) => ({ [name]: { value, description, deprecationReason } });

describe('buildEnumValueConfigMap()', () => {
  it('should work with minimal AST', () => {
    expect((0, _buildEnum.buildEnumValueConfigMap)(generateEnumAST())).toEqual(generateEnumValueConfigMap());
  });

  it('should work with description in AST', () => {
    const description = 'Another description.';
    expect((0, _buildEnum.buildEnumValueConfigMap)(generateEnumAST({
      values: [`# ${ description }\nVALUE`]
    }))).toEqual(generateEnumValueConfigMap({ description }));
  });

  it('should work with `value` in config map', () => {
    const value = 'value';
    expect((0, _buildEnum.buildEnumValueConfigMap)(generateEnumAST(), { VALUE: { value } })).toEqual(generateEnumValueConfigMap({ value }));
  });

  it('should work with `deprecationReason` in config map', () => {
    const deprecationReason = 'A reason.';
    expect((0, _buildEnum.buildEnumValueConfigMap)(generateEnumAST(), { VALUE: { deprecationReason } })).toEqual(generateEnumValueConfigMap({ deprecationReason }));
  });
});

describe('buildEnum()', () => {
  const generateEnumType = ({
    name = 'Enum',
    values = generateEnumValueConfigMap(),
    description
  } = {}) => new _type.GraphQLEnumType({ name, values, description });

  it('should work with minimal AST', () => {
    expect((0, _buildEnum2.default)(generateEnumAST())).toEqual(generateEnumType());
  });

  it('should work with description in AST', () => {
    const config = { description: 'A description.' };
    expect((0, _buildEnum2.default)(generateEnumAST(config))).toEqual(generateEnumType(config));
  });

  it('should work with `values` in config', () => {
    const config = { values: { VALUE: { value: 'value' } } };
    expect((0, _buildEnum2.default)(generateEnumAST(), config)).toEqual(generateEnumType(config));
  });
});