'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _comparators = require('./comparators');

var _buildInputObject = require('../buildInputObject');

var _buildInputObject2 = _interopRequireDefault(_buildInputObject);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */

const generateInputObjectAST = ({
  description,
  name = 'Object',
  fields = { field: 'Int' }
} = {}) => (0, _language.parse)(`
  # ${ description === undefined ? '' : description }
  input ${ name } {
    ${ Object.entries(fields).map(entry => entry.join(': ')).join('\n') }
  }
`).definitions[0];

describe('buildInputObjectConfigFieldMap()', () => {
  const generateInputObjectConfigFieldMap = ({
    name = 'field',
    type = _type.GraphQLInt,
    defaultValue,
    description
  } = {}) => ({ [name]: { type, defaultValue, description } });

  it('should work with minimal AST', () => {
    expect((0, _buildInputObject.buildInputObjectConfigFieldMap)(generateInputObjectAST())).toEqual(generateInputObjectConfigFieldMap());
  });

  it('should work with description in AST', () => {
    const description = 'A description.';
    expect((0, _buildInputObject.buildInputObjectConfigFieldMap)(generateInputObjectAST({
      fields: { [`# ${ description }\nfield`]: 'Int' }
    }))).toEqual(generateInputObjectConfigFieldMap({ description }));
  });

  it('should work with default value in AST', () => {
    expect((0, _buildInputObject.buildInputObjectConfigFieldMap)(generateInputObjectAST({
      fields: { field: 'Int = 0' }
    }))).toEqual(generateInputObjectConfigFieldMap({ defaultValue: 0 }));
  });
});

describe('buildInputObject()', () => {
  const generateInputObjectType = ({
    name = 'Object',
    fields = { field: { type: _type.GraphQLInt } },
    description
  } = {}) => new _type.GraphQLInputObjectType({ name, fields, description });

  it('should work with minimal AST', () => {
    (0, _comparators.expectTypesEqual)((0, _buildInputObject2.default)(generateInputObjectAST()), generateInputObjectType());
  });

  it('should work with description in AST', () => {
    const config = { description: 'A description.' };
    (0, _comparators.expectTypesEqual)((0, _buildInputObject2.default)(generateInputObjectAST(config)), generateInputObjectType(config));
  });
});