'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _comparators = require('./comparators');

var _buildInterface = require('../buildInterface');

var _buildInterface2 = _interopRequireDefault(_buildInterface);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */

describe('buildInterface()', () => {
  const generateInterfaceAST = ({
    description,
    name = 'Interface',
    fields = { field: 'Int' }
  } = {}) => (0, _language.parse)(`
    # ${ description === undefined ? '' : description }
    interface ${ name } {
      ${ Object.entries(fields).map(entry => entry.join(': ')).join('\n') }
    }
  `).definitions[0];
  const generateInterfaceType = ({
    name = 'Interface',
    fields = { field: { type: _type.GraphQLInt } },
    resolveType,
    description
  } = {}) => new _type.GraphQLInterfaceType({ name, fields, resolveType, description });

  it('should work with minimal AST', () => {
    (0, _comparators.expectTypesEqual)((0, _buildInterface2.default)(generateInterfaceAST()), generateInterfaceType());
  });

  it('should work with description in AST', () => {
    const config = { description: 'A description.' };
    (0, _comparators.expectTypesEqual)((0, _buildInterface2.default)(generateInterfaceAST(config)), generateInterfaceType(config));
  });

  it('should work with `resolve` shortcut', () => {
    const resolve = () => {};
    (0, _comparators.expectTypesEqual)((0, _buildInterface2.default)(generateInterfaceAST(), { field: resolve }), generateInterfaceType({ fields: { field: { type: _type.GraphQLInt, resolve } } }));
  });

  it('should work with `fields` in config', () => {
    const deprecationReason = 'A reason.';
    (0, _comparators.expectTypesEqual)((0, _buildInterface2.default)(generateInterfaceAST(), { fields: { field: { deprecationReason } } }), generateInterfaceType({ fields: { field: { type: _type.GraphQLInt, deprecationReason } } }));
  });

  it('should work with `resolveType` in config', () => {
    const config = { resolveType() {} };
    (0, _comparators.expectTypesEqual)((0, _buildInterface2.default)(generateInterfaceAST(), config), generateInterfaceType(config));
  });
});