'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _comparators = require('./comparators');

var _buildObject = require('../buildObject');

var _buildObject2 = _interopRequireDefault(_buildObject);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */

describe('buildObject()', () => {
  const generateObjectAST = ({
    description,
    name = 'Object',
    interfaces = [],
    fields = { field: 'Int' }
  } = {}) => (0, _language.parse)(`
    # ${ description === undefined ? '' : description }
    type ${ name } ${ interfaces.length ? `implements ${ interfaces.join(', ') }` : '' } {
      ${ Object.entries(fields).map(entry => entry.join(': ')).join('\n') }
    }
  `).definitions[0];
  const generateObjectType = ({
    name = 'Object',
    interfaces,
    fields = { field: { type: _type.GraphQLInt } },
    isTypeOf,
    description
  } = {}) => new _type.GraphQLObjectType({ name, interfaces, fields, isTypeOf, description });

  it('should work with minimal AST', () => {
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST()), generateObjectType());
  });

  it('should work with description in AST', () => {
    const config = { description: 'A description.' };
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST(config)), generateObjectType(config));
  });

  it('should work with interfaces in AST', () => {
    const Interface = new _type.GraphQLInterfaceType({ name: 'Interface', resolveType() {} });
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST({ interfaces: ['Interface'] }), undefined, [Interface]), generateObjectType({ interfaces: [Interface] }));
  });

  it('should work with `resolve` shortcut', () => {
    const resolve = () => {};
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST(), { field: resolve }), generateObjectType({ fields: { field: { type: _type.GraphQLInt, resolve } } }));
  });

  it('should work with `fields` in config', () => {
    const deprecationReason = 'A reason.';
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST(), { fields: { field: { deprecationReason } } }), generateObjectType({ fields: { field: { type: _type.GraphQLInt, deprecationReason } } }));
  });

  it('should work with `isTypeOf` in config', () => {
    const config = { isTypeOf() {} };
    (0, _comparators.expectTypesEqual)((0, _buildObject2.default)(generateObjectAST(), config), generateObjectType(config));
  });
});