'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _buildScalar = require('../buildScalar');

var _buildScalar2 = _interopRequireDefault(_buildScalar);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('buildScalar()', () => {
  const generateScalarAST = ({ description, name = 'Scalar' } = {}) => (0, _language.parse)(`
    # ${ description === undefined ? '' : description }
    scalar ${ name }
  `).definitions[0];
  const generateScalarType = ({
    name = 'Scalar',
    description,
    serialize,
    parseValue,
    parseLiteral
  } = {}) => new _type.GraphQLScalarType({ name, description, serialize, parseValue, parseLiteral });

  it('should throw with without `serialize` in config', () => {
    expect(() => (0, _buildScalar2.default)(generateScalarAST())).toThrow();
  });

  it('should work with `serialize` in config', () => {
    const config = { serialize() {} };
    expect((0, _buildScalar2.default)(generateScalarAST(), config)).toEqual(generateScalarType(config));
  });

  it('should work with `serialize` in config and description in AST', () => {
    const config = { description: 'A description', serialize() {} };
    expect((0, _buildScalar2.default)(generateScalarAST(config), config)).toEqual(generateScalarType(config));
  });

  it('should work with `serialize`, `parseValue`, and `parseLiteral` in config', () => {
    const config = { serialize() {}, parseValue() {}, parseLiteral() {} };
    expect((0, _buildScalar2.default)(generateScalarAST(), config)).toEqual(generateScalarType(config));
  });

  it('should work with GraphQL scalar type', () => {
    const config = { serialize() {} };
    expect((0, _buildScalar2.default)(generateScalarAST(), generateScalarType(config))).toEqual(generateScalarType(config));
  });
}); /* eslint-env jest */