'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _buildSchema = require('../buildSchema');

var _buildSchema2 = _interopRequireDefault(_buildSchema);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const generateSchemaAST = ({ query = 'Query', mutation, subscription } = {}) => (0, _language.parse)(`
  schema {
    ${ query == null ? '' : `query: ${ query }` }
    ${ mutation === undefined ? '' : `mutation: ${ mutation }` }
    ${ subscription === undefined ? '' : `subscription: ${ subscription }` }
  }
`).definitions[0]; /* eslint-env jest */

const generateObjectType = name => new _type.GraphQLObjectType({
  name,
  fields: { field: { type: _type.GraphQLInt } }
});
const typeDependencies = [generateObjectType('Query')];

describe('buildOperation()', () => {
  it('should work', () => {
    expect((0, _buildSchema.buildOperation)(generateSchemaAST(), 'query', typeDependencies));
  });
});

describe('buildSchema()', () => {
  const generateSchema = ({
    query = generateObjectType('Query'),
    mutation,
    subscription,
    types,
    directives
  } = {}) => new _type.GraphQLSchema({ query, mutation, subscription, types, directives });

  it('should throw without query in AST', () => {
    const Mutation = generateObjectType('Mutation');
    const Subscription = generateObjectType('Subscription');
    expect(() => (0, _buildSchema2.default)(generateSchemaAST({
      query: null, mutation: Mutation.name, subscription: Subscription.name
    }), undefined, [Mutation, Subscription])).toThrow();
  });

  it('should work with query in AST', () => {
    expect((0, _buildSchema2.default)(generateSchemaAST(), undefined, typeDependencies)).toEqual(generateSchema());
  });

  it('should work with query and mutation in AST', () => {
    const Mutation = generateObjectType('Mutation');
    expect((0, _buildSchema2.default)(generateSchemaAST({
      mutation: Mutation.name
    }), undefined, [...typeDependencies, Mutation])).toEqual(generateSchema({ mutation: Mutation }));
  });

  it('should work with query and subscription in AST', () => {
    const Subscription = generateObjectType('Subscription');
    expect((0, _buildSchema2.default)(generateSchemaAST({
      subscription: Subscription.name
    }), undefined, [...typeDependencies, Subscription])).toEqual(generateSchema({
      subscription: Subscription
    }));
  });

  it('should work with `types` in config', () => {
    const config = { types: [] };
    expect((0, _buildSchema2.default)(generateSchemaAST(), config, typeDependencies)).toEqual(generateSchema(config));
  });

  it('should work with `directives` in config', () => {
    const config = { directives: [] };
    expect((0, _buildSchema2.default)(generateSchemaAST(), config, typeDependencies)).toEqual(generateSchema(config));
  });
});