'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _buildUnion = require('../buildUnion');

var _buildUnion2 = _interopRequireDefault(_buildUnion);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('buildUnion()', () => {
  const generateUnionAST = ({
    description,
    name = 'Union',
    types = 'Int | Float| String | Boolean | ID'
  } = {}) => (0, _language.parse)(`
    # ${ description === undefined ? '' : description }
    union ${ name } = ${ types }
  `).definitions[0];
  const generateUnionType = ({
    name = 'Union',
    types = [_type.GraphQLInt, _type.GraphQLFloat, _type.GraphQLString, _type.GraphQLBoolean, _type.GraphQLID],
    resolveType,
    description
  } = {}) => new _type.GraphQLUnionType({ name, types, resolveType, description });

  it('should work with minimal AST', () => {
    expect((0, _buildUnion2.default)(generateUnionAST())).toEqual(generateUnionType());
  });

  it('should work with description in AST', () => {
    const config = { description: 'A description' };
    expect((0, _buildUnion2.default)(generateUnionAST(config))).toEqual(generateUnionType(config));
  });

  it('should work with `resolveType` in config', () => {
    const config = { resolveType() {} };
    expect((0, _buildUnion2.default)(generateUnionAST(), config)).toEqual(generateUnionType(config));
  });
}); /* eslint-env jest */