'use strict';

var _type = require('graphql/type');

var _language = require('graphql/language');

var _produceType = require('../produceType');

var _produceType2 = _interopRequireDefault(_produceType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const [{ type: innerTypeAST }, { type: wrappedTypeAST }] = (0, _language.parse)(`
  type Ints {
    int: Int
    nonNullListOfNonNullInt: [Int!]!
  }
`, { noLocation: true }).definitions[0].fields; /* eslint-env jest */

const wrappedType = new _type.GraphQLNonNull(new _type.GraphQLList(new _type.GraphQLNonNull(_type.GraphQLInt)));

describe('getNamedTypeAST()', () => {
  it('should work', () => {
    expect((0, _produceType.getNamedTypeAST)(wrappedTypeAST)).toEqual(innerTypeAST);
  });
});

describe('buildWrappedType()', () => {
  it('should work', () => {
    expect((0, _produceType.buildWrappedType)(_type.GraphQLInt, wrappedTypeAST)).toEqual(wrappedType);
  });
});

describe('resolveThunk()', () => {
  it('should work', () => {
    expect((0, _produceType.resolveThunk)(true)).toBe(true);
    expect((0, _produceType.resolveThunk)(() => true)).toBe(true);
  });
});

describe('produceType()', () => {
  const customTypeAST = (0, _language.parse)(`
    scalar UUID
  `).definitions[0];
  const UUID = new _type.GraphQLScalarType({ name: 'UUID', serialize: String });

  it('should produce GraphQL scalars', () => {
    const typeAST = (0, _language.parse)(`
      type Scalars {
        int: Int
        float: Float
        string: String
        boolean: Boolean
        id: ID
      }
    `).definitions[0];
    expect(typeAST.fields.map(({ type }) => type).map(_produceType2.default)).toEqual([_type.GraphQLInt, _type.GraphQLFloat, _type.GraphQLString, _type.GraphQLBoolean, _type.GraphQLID]);
  });

  it('should produce GraphQL type wrappers', () => {
    expect((0, _produceType2.default)(wrappedTypeAST, [])).toEqual(wrappedType);
  });

  it('should produce custom types', () => {
    expect((0, _produceType2.default)(customTypeAST, [UUID])).toEqual(UUID);
  });

  it('should throw if it can\'t produce the type', () => {
    expect(() => (0, _produceType2.default)(customTypeAST, [])).toThrowError('Type "UUID" not found.');
  });
});